@@ -3,7 +3,7 @@ from pathlib import Path
 from typing import Any, Dict, List
 
 from .config import Config
-from .utils.formats import format_json, to_win
+from .utils.formats import format_json
 
 
 def repack_objects(base_path: Path) -> List[Dict[str, Any]]:
@@ -20,7 +20,7 @@ def repack_objects(base_path: Path) -> List[Dict[str, Any]]:
         obj["GUID"] = guid
         script_path = path.joinpath("script.lua")
         if script_path.exists():
-            obj["LuaScript"] = to_win(script_path.read_text())
+            obj["LuaScript"] = script_path.read_text()
         else:
             obj["LuaScript"] = ""
         if path.joinpath("contained").is_dir():
@@ -34,7 +34,7 @@ def repack(*, savegame: Path, config: Config) -> None:
     game = json.loads(config.savegame.read_text())
 
     global_script = config.global_script.read_text()
-    game["LuaScript"] = to_win(global_script)
+    game["LuaScript"] = global_script
 
     script_state = json.loads(config.script_state.read_text())
     game["LuaScriptState"] = json.dumps(script_state)
@@ -43,7 +43,7 @@ def repack(*, savegame: Path, config: Config) -> None:
     game["Note"] = note
 
     xml_ui = config.xml_ui.read_text()
-    game["XmlUI"] = to_win(xml_ui)
+    game["XmlUI"] = xml_ui
 
     game["ObjectStates"] = repack_objects(config.objects)
 
